library(readxl)
library(ape)
library(picante)
library(geiger)
library(phytools)

####Data and phylogeny

habitats<-read_excel("traits_final.xlsx")
tree<-read.tree("5Feb_dated_tree.tre",tree.names = NULL)



######Correlated evolution: spore type and habitats

##Habit a: epiphytes (1), terrestrials + waterlogged (0)

habita<-as.data.frame(habitats)
habita<-habita[,c(1,2,3)]
row.names(habita)<-habita$Species 
habita<-na.omit(habita)

#prune tree
match<-match.phylo.data(tree,habita)
habita2<-match$data
treea<-match$phy

###tree
write.nexus(treea,file="treea.nexus",translate = T)

###data
habita2<-as.data.frame(habita2)
write.table(habita2,file="habita2.txt",row.names = F, sep="\t",quote = F, col.names = F)

##
##Habit b: epiphytes + waterlogged (1), terrestrial (0)
habitb<-as.data.frame(habitats)
habitb<-habitb[,c(1,2,4)]
row.names(habitb)<-habitb$Species 
habitb<-na.omit(habitb)

#prune tree
match<-match.phylo.data(tree,habitb)
habitb2<-match$data
treeb<-match$phy

###tree
write.nexus(treeb,file="treeb.nexus",translate = T)

###data
habitb2<-as.data.frame(habitb2)
write.table(habitb2,file="habitb2.txt",row.names = F, sep="\t",quote = F, col.names = F)

##
##Habit c: terrestrial (1),  waterlogged (0)
habitc<-as.data.frame(habitats)
habitc<-habitc[,c(1,2,5)]
row.names(habitc)<-habitc$Species 
habitc<-na.omit(habitc)


match<-match.phylo.data(tree,habitc)
habitc2<-match$data
treec<-match$phy

###tree
write.nexus(treec,file="treec.nexus",translate = T)

###data
habitc2<-as.data.frame(habitc2)
write.table(habitc2,file="habitc2.txt",row.names = F, sep="\t",quote = F, col.names = F)

###
##Habit d: epiphytes (1),  terrestrial (0)
habitd<-as.data.frame(habitats)
habitd<-habitd[,c(1,2,6)]
row.names(habitd)<-habitd$Species 
habitd<-na.omit(habitd)


match<-match.phylo.data(tree,habitd)
habitd2<-match$data
treed<-match$phy

###tree
write.nexus(treed,file="treed.nexus",translate = T)

###data
habitd2<-as.data.frame(habitd2)
write.table(habitd2,file="habitd2.txt",row.names = F, sep="\t",quote = F, col.names = F)

###################################################
######Correlated evolution: habitats and mycorrhizal associations

#habit a
myco_a<-read_excel("traits_final.xlsx")
myco_a<-as.data.frame(myco_a)
myco_a<-myco_a[,c(1,3,7)]
row.names(myco_a)<-myco_a$Species 
myco_a<-na.omit(myco_a)


match<-match.phylo.data(tree,myco_a)
myco_a2<-match$data
treema<-match$phy

###tree
write.nexus(treema,file="treema.nexus",translate = T)

###data
myco_a2<-as.data.frame(myco_a2)
write.table(myco_a2,file="myco_a2.txt",row.names = F, sep="\t",quote = F, col.names = F)

##
#habit b

myco_b<-read_excel("traits_final.xlsx")
myco_b<-as.data.frame(myco_b)
myco_b<-myco_b[,c(1,4,7)]
row.names(myco_b)<-myco_b$Species 
myco_b<-na.omit(myco_b)


match<-match.phylo.data(tree,myco_b)
myco_b2<-match$data
treemb<-match$phy

###tree
write.nexus(treemb,file="treemb.nexus",translate = T)

###data
myco_b2<-as.data.frame(myco_b2)
write.table(myco_b2,file="myco_b2.txt",row.names = F, sep="\t",quote = F, col.names = F)


##
#habit c

myco_c<-read_excel("traits_final.xlsx")
myco_c<-as.data.frame(myco_c)
myco_c<-myco_c[,c(1,5,7)]
row.names(myco_c)<-myco_c$Species 
myco_c<-na.omit(myco_c)


match<-match.phylo.data(tree,myco_c)
myco_c2<-match$data
treemc<-match$phy

###tree
write.nexus(treemc,file="treemc.nexus",translate = T)

###data
myco_c2<-as.data.frame(myco_c2)
write.table(myco_c2,file="myco_c2.txt",row.names = F, sep="\t",quote = F, col.names = F)


##
#habit d

myco_d<-read_excel("traits_final.xlsx")
myco_d<-as.data.frame(myco_d)
myco_d<-myco_d[,c(1,6,7)]
row.names(myco_d)<-myco_d$Species 
myco_d<-na.omit(myco_d)


match<-match.phylo.data(tree,myco_d)
myco_d2<-match$data
treemd<-match$phy

###tree
write.nexus(treemd,file="treemd.nexus",translate = T)

###data
myco_d2<-as.data.frame(myco_d2)
write.table(myco_d2,file="myco_d2.txt",row.names = F, sep="\t",quote = F, col.names = F)


##
#spore type and mycorrhiza

micospore<-read_excel("traits_final.xlsx")
micospore<-as.data.frame(micospore)
micospore<-micospore[,c(1,2,7)]
row.names(micospore)<-micospore$Species 
micospore<-na.omit(micospore)


match<-match.phylo.data(tree,micospore)
micospore2<-match$data
treems<-match$phy

###tree
write.nexus(treems,file="treems.nexus",translate = T)

###data
micospore2<-as.data.frame(micospore2)
write.table(micospore2,file="micospore2.txt",row.names = F, sep="\t",quote = F, col.names = F)



