library(phylolm)
library(phytools)
library(rr2)
library(readxl)
library(picante)

####Phylogenetic logistic regressions of spore type vs. habitats###

habitats<-read_excel("traits_final.xlsx")
tree<-read.tree("5Feb_dated_tree.tre",tree.names = NULL)

################################################
#####single-predictor models
##Habit a: epiphytes (1), terrestrials + waterlogged (0)

habita<-as.data.frame(habitats)
habita<-habita[,c(1,2,3)]
row.names(habita)<-habita$Species 
habita<-na.omit(habita)

#prune tree
match<-match.phylo.data(tree,habita)
habita2<-match$data
treea<-match$phy

treea2<-force.ultrametric(treea)

habita2<-as.data.frame(habita2)
habita2$spore_type <- as.factor(habita2$spore_type)
habita2$habit_a<-as.factor(habita2$habit_a)
habita2$Species <-habita2$Species 

spore_habita<-phyloglm(habit_a~spore_type, phy = treea, data=habita2,
                       method = "logistic_MPLE", boot = 100, btol=100,
                       log.alpha.bound=8,start.beta=c(-4,3), start.alpha=0.05)

summary(spore_habita)
R2.lik(spore_habita)

####
##Habit b: epiphytes + waterlogged (1), terrestrial (0)
habitb<-as.data.frame(habitats)
habitb<-habitb[,c(1,2,4)]
row.names(habitb)<-habitb$Species 
habitb<-na.omit(habitb)

#prune tree
match<-match.phylo.data(tree,habitb)
habitb2<-match$data
treeb<-match$phy

treeb2<-force.ultrametric(treeb)

habitb2<-as.data.frame(habitb2)
habitb2$spore_type <- as.factor(habitb2$spore_type)
habitb2$habit_b<-as.factor(habitb2$habit_b)
habitb2$Species <-habitb2$Species

spore_habitb<-phyloglm(habit_b~spore_type,method = "logistic_MPLE", phy=treeb2, 
                       data = habitb2, boot = 100)
summary(spore_habitb)
R2.lik(spore_habitb)

###
##Habit c: terrestrial (1),  waterlogged (0)
habitc<-as.data.frame(habitats)
habitc<-habitc[,c(1,2,5)]
row.names(habitc)<-habitc$Species 
habitc<-na.omit(habitc)


match<-match.phylo.data(tree,habitc)
habitc2<-match$data
treec<-match$phy
treec2<-force.ultrametric(treec)

habitc2<-as.data.frame(habitc2)

habitc2$spore_type <- as.factor(habitc2$spore_type)
habitc2$habit_c<-as.factor(habitc2$habit_c)
habitc2$Species <-habitc2$Species

spore_habitc<-phyloglm(habit_c~spore_type,method = "logistic_MPLE", phy=treec2, 
                       data = habitc2, boot = 100)

summary(spore_habitc)
R2.lik(spore_habitc)

###
##Habit d: epiphytes (1),  terrestrial (0)
habitd<-as.data.frame(habitats)
habitd<-habitd[,c(1,2,6)]
row.names(habitd)<-habitd$Species 
habitd<-na.omit(habitd)


match<-match.phylo.data(tree,habitd)
habitd2<-match$data
treed<-match$phy
treed2<-force.ultrametric(treed)

habitd2<-as.data.frame(habitd2)

habitd2$spore_type <- as.factor(habitd2$spore_type)
habitd2$habit_d<-as.factor(habitd2$habit_d)
habitd2$Species <-habitd2$Species

spore_habitd<-phyloglm(habit_d~spore_type,method = "logistic_MPLE", phy=treed2, 
                       data = habitd2, boot = 100)
summary(spore_habitd)
R2.lik(spore_habitd)

##
#Spore type and mycorrhizal associations
spore_myco<-as.data.frame(habitats)
spore_myco<-spore_myco[,c(1,2,7)]
row.names(spore_myco)<-spore_myco$Species 
spore_myco<-na.omit(spore_myco)

match<-match.phylo.data(tree,spore_myco)
spore_myco2<-match$data
treesm<-match$phy
treesm2<-force.ultrametric(treesm)

spore_myco2<-as.data.frame(spore_myco2)
spore_myco2$spore_type<-as.factor(spore_myco2$spore_type)
spore_myco2$mycorrhiza<-as.factor(spore_myco2$mycorrhiza)

myco_spore<-phyloglm(mycorrhiza~spore_type, phy = treesm2, data=spore_myco2,
                     method="logistic_MPLE",boot = 100)
summary(myco_spore)
R2.lik(myco_spore)

################################################
###multipredictor models
####Spore type, mycorrhizal, and habitats

#habit a
st_my_ha<-as.data.frame(habitats)
st_my_ha<-st_my_ha[,c(1,2,3,7)]
row.names(st_my_ha)<-st_my_ha$Species 
st_my_ha<-na.omit(st_my_ha)


match<-match.phylo.data(tree,st_my_ha)
st_my_ha2<-match$data
treesma<-match$phy

st_my_ha2<-as.data.frame(st_my_ha2)

mikoa_glm<-phyloglm(habit_a~spore_type*mycorrhiza, phy = treesma,
                    data=st_my_ha2, method="logistic_MPLE",boot = 100)
summary(mikoa_glm)
mikoa_glm$aic
#248.0892
mikoa_glm2<-phyloglm(habit_a~spore_type+mycorrhiza, phy = treesma, 
                     data=st_my_ha2,method="logistic_MPLE",boot = 100)
summary(mikoa_glm2)
mikoa_glm2$aic
#249.4025


##
#habit b
st_my_hb<-as.data.frame(habitats)
st_my_hb<-st_my_hb[,c(1,2,4,7)]
row.names(st_my_hb)<-st_my_hb$Species 
st_my_hb<-na.omit(st_my_hb)

match<-match.phylo.data(tree,st_my_hb)
st_my_hb2<-match$data
treesmb<-match$phy

st_my_hb2<-as.data.frame(st_my_hb2)
st_my_hb2$spore_type<-as.factor(st_my_hb2$spore_type)
st_my_hb2$habit_b<-as.factor(st_my_hb2$habit_b)
st_my_hb2$mycorrhiza<-as.factor(st_my_hb2$mycorrhiza)

mikob_glm<-phyloglm(habit_b~spore_type*mycorrhiza, phy = treesmb,
                    data=st_my_hb2, method="logistic_MPLE",boot = 100)
summary(mikob_glm)
mikob_glm$aic
#296.8444
mikob_glm2<-phyloglm(habit_b~spore_type+mycorrhiza, phy = treesmb, 
                     data=st_my_hb2,method="logistic_MPLE",boot = 100)
summary(mikob_glm2)
mikob_glm2$aic
#296.9225


##
#habit c
st_my_hc<-as.data.frame(habitats)
st_my_hc<-st_my_hc[,c(1,2,5,7)]
row.names(st_my_hc)<-st_my_hc$Species 
st_my_hc<-na.omit(st_my_hc)


match<-match.phylo.data(tree,st_my_hc)
st_my_hc2<-match$data
treesmc<-match$phy

st_my_hc2<-as.data.frame(st_my_hc2)

mikoc_glm<-phyloglm(habit_c~spore_type*mycorrhiza, phy = treesmc,
                    data=st_my_hc2, method="logistic_MPLE",boot = 100)
summary(mikoc_glm)
mikoc_glm$aic
#115.0133
mikoc_glm2<-phyloglm(habit_c~spore_type+mycorrhiza, phy = treesmc, 
                     data=st_my_hc2,method="logistic_MPLE",boot = 100)
summary(mikoc_glm2)
mikoc_glm2$aic
#113.7928


##
#habit d
st_my_hd<-as.data.frame(habitats)
st_my_hd<-st_my_hd[,c(1,2,6,7)]
row.names(st_my_hd)<-st_my_hd$Species 
st_my_hd<-na.omit(st_my_hd)

match<-match.phylo.data(tree,st_my_hd)
st_my_hd2<-match$data
treesmd<-match$phy

st_my_hd2<-as.data.frame(st_my_hd2)

st_my_hd2$spore_type<-as.factor(st_my_hd2$spore_type)
st_my_hd2$mycorrhiza<-as.factor(st_my_hd2$mycorrhiza)
st_my_hd2$habit_d<-as.factor(st_my_hd2$habit_d)


mikod_glm<-phyloglm(habit_d~spore_type*mycorrhiza, phy = treesmd,
                    data=st_my_hd2, method="logistic_MPLE",boot = 100)
summary(mikod_glm)
mikod_glm$aic
#239.9994
mikod_glm2<-phyloglm(habit_d~spore_type+mycorrhiza, phy = treemikod, 
                     data=st_my_hd2,method="logistic_MPLE",boot = 100)
summary(mikod_glm2)
mikod_glm2$aic
#240.7816

###########################################################################
########Mycorrhizal associations and habitats

my_ha_a<-as.data.frame(habitats)
my_ha_a<-my_ha_a[,c(1,3,7)]
row.names(my_ha_a)<-my_ha_a$Species 
my_ha_a<-na.omit(my_ha_a)

#prune tree
match<-match.phylo.data(tree,my_ha_a)
my_ha_a2<-match$data
treemha<-match$phy

treemha2<-force.ultrametric(treemha)

my_ha_a2<-as.data.frame(my_ha_a2)
my_ha_a2$mycorrhiza <- as.factor(my_ha_a2$mycorrhiza)
my_ha_a2$habit_a<-as.factor(my_ha_a2$habit_a)
my_ha_a2$Species <-my_ha_a2$Species 

myco_habita<-phyloglm(habit_a~mycorrhiza, phy = treemha2, data=my_ha_a2,
                       method = "logistic_MPLE", boot = 100, btol=100,
                      log.alpha.bound=8,start.beta=c(-4,3), start.alpha=0.05)

summary(myco_habita)
R2.lik(myco_habita)

####
##Habit b: epiphytes + waterlogged (1), terrestrial (0)
my_ha_b<-as.data.frame(habitats)
my_ha_b<-my_ha_b[,c(1,4,7)]
row.names(my_ha_b)<-my_ha_b$Species 
my_ha_b<-na.omit(my_ha_b)

#prune tree
match<-match.phylo.data(tree,my_ha_b)
my_ha_b2<-match$data
treemhb<-match$phy

treemhb2<-force.ultrametric(treemhb)

my_ha_b2<-as.data.frame(my_ha_b2)
my_ha_b2$mycorrhiza <- as.factor(my_ha_b2$mycorrhiza)
my_ha_b2$habit_b<-as.factor(my_ha_b2$habit_b)
my_ha_b2$Species <-my_ha_b2$Species

myco_habitb<-phyloglm(habit_b~mycorrhiza,method = "logistic_MPLE", phy=treemhb2, data = my_ha_b2, boot = 100)
summary(myco_habitb)
R2.lik(myco_habitb)

###
##Habit c: terrestrial (1),  waterlogged (0)
my_ha_c<-as.data.frame(habitats)
my_ha_c<-my_ha_c[,c(1,5,7)]
row.names(my_ha_c)<-my_ha_c$Species 
my_ha_c<-na.omit(my_ha_c)


match<-match.phylo.data(tree,my_ha_c)
my_ha_c2<-match$data
treemhc<-match$phy
treemhc2<-force.ultrametric(treemhc)

my_ha_c2<-as.data.frame(my_ha_c2)

my_ha_c2$mycorrhiza <- as.factor(my_ha_c2$mycorrhiza)
my_ha_c2$habit_c<-as.factor(my_ha_c2$habit_c)
my_ha_c2$Species <-my_ha_c2$Species

myco_habitc<-phyloglm(habit_c~mycorrhiza,method = "logistic_MPLE", phy=treemhc2, data = my_ha_c2, boot = 100)

summary(myco_habitc)
R2.lik(myco_habitc)

###
##Habit d: epiphytes (1),  terrestrial (0)
my_ha_d<-as.data.frame(habitats)
my_ha_d<-my_ha_d[,c(1,6,7)]
row.names(my_ha_d)<-my_ha_d$Species 
my_ha_d<-na.omit(my_ha_d)


match<-match.phylo.data(tree,my_ha_d)
my_ha_d2<-match$data
treemhd<-match$phy
treemhd2<-force.ultrametric(treemhd)

my_ha_d2<-as.data.frame(my_ha_d2)

my_ha_d2$spore_type <- as.factor(my_ha_d2$mycorrhiza)
my_ha_d2$habit_d<-as.factor(my_ha_d2$habit_d)
my_ha_d2$Species <-my_ha_d2$Species

myco_habitd<-phyloglm(habit_d~mycorrhiza,method = "logistic_MPLE", phy=treemhd2, data = my_ha_d2, boot = 100)
summary(myco_habitd)
R2.lik(myco_habitd)



