library(ggtree)
library(picante)
library(readxl)
library(dplyr)
library(ape)
library(ggplot2)
library(phytools)
library(geiger)
library(ggnewscale)
library(tidyverse)


#phylogeny
tree<-read.tree("5Feb_dated_tree.tre",tree.names = NULL)

#data
traits <- read_excel("ggtree.xlsx")
traits<-as.data.frame(traits)
table(traits$Subfamilies)
row.names(traits)<-traits$Species 


matchgg<-match.phylo.data(tree,traits)
treegg<-(matchgg$phy)
traitsgg<-(matchgg$data)


###traits 
traitsplot<-as.data.frame(traitsgg)

spore<-traitsplot[,"Spore_type"] %>% as.data.frame()
class(spore);names(spore) <- "Spore_type"
row.names(spore)<-treegg$tip.label

habit<-traitsplot[,"Habitat"] %>% as.data.frame()
class(habit);names(habit) <- "Habitat"
row.names(habit)<-treegg$tip.label

fam<-traitsplot[,"Subfamilies"] %>% as.data.frame()
class(fam);names(fam) <- "Subfamilies"
row.names(fam)<-treegg$tip.label
table(fam)

myco<-traitsplot[,"Mycorrhiza"] %>% as.data.frame()
class(myco);names(myco) <- "Mycorrhiza"
row.names(myco)<-treegg$tip.label

######################
M<-ggtree(treegg, layout = "fan",ladderize = T) + xlim_tree(0)
m2<-gheatmap(M,spore, offset=0 ,width=0.1, font.size=0, hjust=0) +
  scale_fill_manual(breaks=c("Chlorophyllous", "Achlorophyllous"), 
                    values=c("forestgreen", "gold2"), name="Spore Type",
                    guide=guide_legend(ncol=2, order=1, title.position = "top"))+
  theme(legend.position="bottom", legend.text = element_text(size = 15),legend.title = element_text(size=14))

m3 <- m2 + new_scale_fill()


m4<-gheatmap(m3,myco, offset=36,width=0.1, font.size=0, hjust=0) +
  scale_fill_manual(breaks=c("Absent", "Present", "no_data"), 
                    values=c("red3", "pink","grey52"), name="Mycorrhiza",
                    guide=guide_legend(ncol=3, order=2, title.position = "top"))+
  theme(legend.position="bottom", legend.text = element_text(size = 15))

m5<-m4+new_scale_fill()
m6 <-gheatmap(m5,habit, offset=76,width=0.1, font.size=0, hjust=0) +
  scale_fill_manual(breaks=c("Epiphytic", "Terrestrial","Waterlogged"),
                    values=c("limegreen", "royalblue2", "skyblue1"), name="Habitat",
                    guide=guide_legend(ncol=3, order=3, title.position="top"))+
  theme(legend.position="bottom", legend.text = element_text(size = 15))


m7<-m6+ new_scale_fill()
m8 <- gheatmap(m7, fam, offset=138,width=0.02, font.size=0, hjust=0) +
  scale_fill_manual(breaks=c("Equisetaceae","Marattiaceae","Psilotaceae","Ophioglossaceae", "Osmundaceae","Gleicheniales","Hymenophyllaceae","Schizaeales", "Cyatheales", "Lindsaeineae","Dennstaedtiaceae","Saccolomataceae","Pteridaceae", "Aspleniineae", "Polypodiineae"),
values=c("yellow","orange","olivedrab3","olivedrab1","lightseagreen","violet","springgreen4","brown","steelblue2","darkorchid2","darkmagenta","indianred","seagreen2","blue","palevioletred1"),
                    guide="none")



families <- read_csv("families.csv")

m9<-m8+geom_cladelab(data = families,mapping=aes(node=node_fam,label=Subfamilies, hjust=0, vjust=0.5), 
                     offset=150, barcolour= "white",offset.text=1,horizontal=T, barsize= .05, fontsize=5)

families2 <- read_csv("families2.csv")

m10<-m9+geom_cladelab(data = families2,mapping=aes(node=node_fam,label=Subfamilies, hjust=1, vjust=4), 
                      offset=150, barcolour= "white",offset.text=1,horizontal=T, barsize= .05, fontsize=5)


families3 <- read_csv("families3.csv")
m11<-m10+geom_cladelab(data = families3,mapping=aes(node=node_fam,label=Subfamilies, hjust=1, vjust=0.5), 
                       offset=150, barcolour= "white",offset.text=1,horizontal=T, barsize= .05, fontsize=5)+
  theme(legend.position="bottom",legend.box = "horizontal",
        legend.box.just = "bottom", legend.justification=c(0.5, 1),
        legend.margin =margin(r=10,l=10,t=10,b=10),legend.text = element_text(size = 15))

m11

